==> wikitty-api-3.0.4-test-sources.jar: org/nuiton/wikitty/services/WikittyCacheJCSTest.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id: WikittyCacheJCSTest.java 678 2011-01-10 21:25:07Z sletellier $
 * $HeadURL: http://svn.nuiton.org/svn/wikitty/tags/wikitty-3.0.4/wikitty-api/src/test/java/org/nuiton/wikitty/services/WikittyCacheJCSTest.java $
 * %%
 * Copyright (C) 2009 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.services;


import junit.framework.Assert;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.Test;
import org.nuiton.wikitty.WikittyConfig;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyImpl;

/**
 *
 * @author poussin
 * @version $Revision: 678 $
 *
 * Last update: $Date: 2011-01-10 22:25:07 +0100 (lun., 10 janv. 2011) $
 * by : $Author: sletellier $
 */
public class WikittyCacheJCSTest {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static private Log log = LogFactory.getLog(WikittyCacheJCSTest.class);

    @Test
    public void testPutGet() throws Exception {
        WikittyConfig config = new WikittyConfig();
        WikittyCacheJCS cache = new WikittyCacheJCS(config);

        Wikitty w = new WikittyImpl();
        cache.putWikitty(w);

        Wikitty w2 = cache.getWikitty(w.getId());

        Assert.assertEquals(w, w2);
    }

}

==> wikitty-api-3.0.5-test-sources.jar: org/nuiton/wikitty/services/WikittyCacheJCSTest.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id: WikittyCacheJCSTest.java 738 2011-02-24 14:50:00Z echatellier $
 * $HeadURL: http://svn.nuiton.org/svn/wikitty/tags/wikitty-3.0.5/wikitty-api/src/test/java/org/nuiton/wikitty/services/WikittyCacheJCSTest.java $
 * %%
 * Copyright (C) 2009 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.services;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.Assert;
import org.junit.Test;
import org.nuiton.wikitty.WikittyConfig;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyImpl;

/**
 *
 * @author poussin
 * @version $Revision: 738 $
 *
 * Last update: $Date: 2011-02-24 15:50:00 +0100 (jeu. 24 févr. 2011) $
 * by : $Author: echatellier $
 */
public class WikittyCacheJCSTest {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static private Log log = LogFactory.getLog(WikittyCacheJCSTest.class);

    @Test
    public void testPutGet() throws Exception {
        WikittyConfig config = new WikittyConfig();
        WikittyCacheJCS cache = new WikittyCacheJCS(config);

        Wikitty w = new WikittyImpl();
        cache.putWikitty(w);

        Wikitty w2 = cache.getWikitty(w.getId());

        Assert.assertEquals(w, w2);
    }

}
